==> ntgcalls-1.3.2.tar.gz: ntgcalls-1.3.2/cmake/PythonUtils.cmake <==
function(PythonFindAllRegex)
    set(OUTPUT "")
    foreach(arg ${ARGN})
        set(OUTPUT ${arg})
    endforeach()
    cmake_parse_arguments(ARG "" "" "REGEX;STRING;" ${ARGN})
    string(REPLACE "'" "\\'" ARG_REGEX ${ARG_REGEX})
    string(REPLACE "\n" "\\n" ARG_STRING ${ARG_STRING})
    string(REPLACE "'" "\\'" ARG_STRING ${ARG_STRING})
    set(TEMP_PYTHON_FILE ${deps_loc}/_tmp.py)
    set(PYTHON_CONTENT "import re\n")
    set(PYTHON_CONTENT "${PYTHON_CONTENT}found_res = re.findall(r'${ARG_REGEX}', '${ARG_STRING}')\n")
    set(PYTHON_CONTENT "${PYTHON_CONTENT}for res in found_res:\n")
    set(PYTHON_CONTENT "${PYTHON_CONTENT}    if isinstance(res, str):\n")
    set(PYTHON_CONTENT "${PYTHON_CONTENT}        res = (res,)\n")
    set(PYTHON_CONTENT "${PYTHON_CONTENT}    for group in res:\n")
    set(PYTHON_CONTENT "${PYTHON_CONTENT}        print(group)\n")
    set(PYTHON_CONTENT "${PYTHON_CONTENT}    print(f\"--end-group--\")\n")
    file(WRITE ${TEMP_PYTHON_FILE} ${PYTHON_CONTENT})
    execute_process(
        COMMAND ${Python3_EXECUTABLE} ${TEMP_PYTHON_FILE}
        OUTPUT_VARIABLE RESULT
    )
    file(REMOVE ${TEMP_PYTHON_FILE})
    if (NOT RESULT)
        unset(${OUTPUT} PARENT_SCOPE)
        return()
    endif()
    string(STRIP ${RESULT} RESULT)

    string(REGEX REPLACE "\n" ";" DATA_REGEX "${RESULT}")
    set(MATCHES)
    set(SUB_MATCHES)
    foreach(line ${DATA_REGEX})
        if (line STREQUAL "--end-group--")
            list(APPEND MATCHES "${SUB_MATCHES}")
            set(SUB_MATCHES)
        else ()
            list(APPEND SUB_MATCHES ${line})
        endif ()
    endforeach ()
    set(${OUTPUT} ${MATCHES} PARENT_SCOPE)
endfunction()

==> ntgcalls-2.0.5.tar.gz: ntgcalls-2.0.5/cmake/PythonUtils.cmake <==
function(PythonFindAllRegex)
    set(OUTPUT "")
    foreach(arg ${ARGN})
        set(OUTPUT ${arg})
    endforeach()
    cmake_parse_arguments(ARG "" "" "REGEX;STRING;" ${ARGN})
    string(REPLACE "'" "\\'" ARG_REGEX ${ARG_REGEX})
    string(REPLACE "\n" "\\n" ARG_STRING ${ARG_STRING})
    string(REPLACE "'" "\\'" ARG_STRING ${ARG_STRING})
    set(TEMP_PYTHON_FILE ${DEPS_DIR}/_tmp.py)
    set(PYTHON_CONTENT "import re\n")
    set(PYTHON_CONTENT "${PYTHON_CONTENT}found_res = re.findall(r'${ARG_REGEX}', '${ARG_STRING}')\n")
    set(PYTHON_CONTENT "${PYTHON_CONTENT}for res in found_res:\n")
    set(PYTHON_CONTENT "${PYTHON_CONTENT}    if isinstance(res, str):\n")
    set(PYTHON_CONTENT "${PYTHON_CONTENT}        res = (res,)\n")
    set(PYTHON_CONTENT "${PYTHON_CONTENT}    for group in res:\n")
    set(PYTHON_CONTENT "${PYTHON_CONTENT}        print(group)\n")
    set(PYTHON_CONTENT "${PYTHON_CONTENT}    print(f\"--end-group--\")\n")
    file(WRITE ${TEMP_PYTHON_FILE} ${PYTHON_CONTENT})
    execute_process(
        COMMAND ${Python3_EXECUTABLE} ${TEMP_PYTHON_FILE}
        OUTPUT_VARIABLE RESULT
    )
    file(REMOVE ${TEMP_PYTHON_FILE})
    if (NOT RESULT)
        unset(${OUTPUT} PARENT_SCOPE)
        return()
    endif()
    string(STRIP ${RESULT} RESULT)

    string(REGEX REPLACE "\n" ";" DATA_REGEX "${RESULT}")
    set(MATCHES)
    set(SUB_MATCHES)
    foreach(line ${DATA_REGEX})
        if (line STREQUAL "--end-group--")
            list(APPEND MATCHES "${SUB_MATCHES}")
            set(SUB_MATCHES)
        else ()
            list(APPEND SUB_MATCHES ${line})
        endif ()
    endforeach ()
    set(${OUTPUT} ${MATCHES} PARENT_SCOPE)
endfunction()
